@@ -6,6 +6,10 @@ class CkanBaseController(BaseController):
         # what is different between session['user'] and environ['REMOTE_USER']
         c.user = request.environ.get('REMOTE_USER', None)
         c.remote_addr = request.environ.get('REMOTE_ADDR', 'Unknown IP Address')
+        if c.remote_addr == 'localhost' or c.remote_addr == '127.0.0.1':
+            # see if it was proxied
+            c.remote_addr = request.environ.get('HTTP_X_FORWARDED_FOR',
+                    '127.0.0.1')
         if c.user:
             c.author = c.user
         else:
